# SubscriptionObjectQTFields

Container for Subscription fields provided by Zuora Quotes. 

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cpq_bundle_json_id__qt** | **str** | The Bundle product structures from Zuora Quotes if you utilize Bundling in Salesforce. Do not change the value in this field.  | [optional] 
**opportunity_close_date__qt** | **date** | The closing date of the Opportunity. This field is used in Zuora data sources to report on Subscription metrics. If the subscription originated from Zuora Quotes, the value is populated with the value from Zuora Quotes.  | [optional] 
**opportunity_name__qt** | **str** | The unique identifier of the Opportunity. This field is used in Zuora data sources to report on Subscription metrics. If the subscription originated from Zuora Quotes, the value is populated with the value from Zuora Quotes.  | [optional] 
**quote_business_type__qt** | **str** | The specific identifier for the type of business transaction the Quote represents such as New, Upsell, Downsell, Renewal or Churn. This field is used in Zuora data sources to report on Subscription metrics. If the subscription originated from Zuora Quotes, the value is populated with the value from Zuora Quotes.  | [optional] 
**quote_number__qt** | **str** | The unique identifier of the Quote. This field is used in Zuora data sources to report on Subscription metrics. If the subscription originated from Zuora Quotes, the value is populated with the value from Zuora Quotes.  | [optional] 
**quote_type__qt** | **str** | The Quote type that represents the subscription lifecycle stage such as New, Amendment, Renew or Cancel. This field is used in Zuora data sources to report on Subscription metrics. If the subscription originated from Zuora Quotes, the value is populated with the value from Zuora Quotes.  | [optional] 

## Example

```python
from zuora_sdk.models.subscription_object_qt_fields import SubscriptionObjectQTFields

# TODO update the JSON string below
json = "{}"
# create an instance of SubscriptionObjectQTFields from a JSON string
subscription_object_qt_fields_instance = SubscriptionObjectQTFields.from_json(json)
# print the JSON string representation of the object
print(SubscriptionObjectQTFields.to_json())

# convert the object into a dict
subscription_object_qt_fields_dict = subscription_object_qt_fields_instance.to_dict()
# create an instance of SubscriptionObjectQTFields from a dict
subscription_object_qt_fields_from_dict = SubscriptionObjectQTFields.from_dict(subscription_object_qt_fields_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


